@@ -1,6 +1,6 @@
 import time
 import datetime
-from src.zcc_utils import math_utils
+import math_utils
 
 
 def second_to_minute(second: int):
